%global major_version 3
Summary:        Cmake
Name:           cmake
Version:        3.30.3
Release:        5%{?dist}
License:        BSD AND LGPLv2+
Vendor:         Microsoft Corporation
Distribution:   Azure Linux
Group:          Development/Tools
URL:            https://www.cmake.org/
Source0:        https://github.com/Kitware/CMake/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        macros.cmake
Patch0:         0001-manually-recreating-patches.patch
Patch1:         CVE-2024-6197.patch
Patch2:         CVE-2024-6874.patch
Patch3:         CVE-2024-8096.patch
Patch4:         CVE-2024-11053.patch
Patch5:         CVE-2024-7264.patch
Patch6:         CVE-2024-9681.patch
Patch7:         CVE-2023-44487.patch
# When upgrading cmake, verify by hand that this patch is actually contained
# within the cmnghttp2 source. The autoupgrader mistakenly removes it. Upstream
# nghttp2 patched this with v1.55.1 and newer. As of cmake v3.30.3, cmake has
# nghttp2 v1.52.0 plus some upstream patches. nghttp2 version can be found in
# Utilities/cmnghttp2/lib/includes/nghttp2/nghttp2ver.h. Manual inspection is
# required to determine what upstream patches are included.
Patch8:         CVE-2023-35945.patch  
BuildRequires:  bzip2
BuildRequires:  bzip2-devel
BuildRequires:  curl
BuildRequires:  curl-devel
BuildRequires:  expat-devel
BuildRequires:  expat-libs
BuildRequires:  libarchive
BuildRequires:  libarchive-devel
BuildRequires:  ncurses-devel
BuildRequires:  xz
BuildRequires:  xz-devel
BuildRequires:  zlib
BuildRequires:  zlib-devel
%if 0%{?with_check}
BuildRequires:  javapackages-tools
BuildRequires:  msopenjdk-17
%endif
Requires:       bzip2
Requires:       expat
Requires:       libarchive
Requires:       ncurses
Requires:       zlib
Provides:       %{name}%{major_version} = %{version}-%{release}
Provides:       %{name}-filesystem = %{version}-%{release}
Provides:       %{name}-filesystem%{?_isa} = %{version}-%{release}

%description
CMake is an extensible, open-source system that manages the build process in an
operating system and in a compiler-independent manner.

%prep
%autosetup -p1

%build
export JAVA_HOME="%{_libdir}/jvm/msopenjdk-17"
./bootstrap \
    --prefix=%{_prefix} \
    --system-expat \
    --system-zlib \
    --system-libarchive \
    --system-bzip2 \
    --parallel=$(nproc)
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
install -Dpm0644 %{SOURCE1} %{buildroot}%{_libdir}/rpm/macros.d/macros.cmake
sed -i -e "s|@@CMAKE_VERSION@@|%{version}|" -e "s|@@CMAKE_MAJOR_VERSION@@|%{major_version}|" %{buildroot}%{_libdir}/rpm/macros.d/macros.cmake

# Collect all license files into one spot
for f in Copyright.txt cmcppdap/NOTICE cmcurl/COPYING cmlibrhash/COPYING cmlibuv/LICENSE cmnghttp2/COPYING cmsys/Copyright.txt; do
    filename_part=$(basename $f)
    dir_part=$(dirname $f)
    mkdir -p ./Licenses/$dir_part
    mv %{buildroot}%{_prefix}/doc/%{name}-*/$f ./Licenses/$dir_part/$filename_part
done
find "%{buildroot}%{_prefix}/doc" -type d -empty -delete

%check
# Removing static libraries to fix issues with the "ParseImplicitLinkInfo" test runs for the "craype-C-Cray-8.7.input" and "craype-CXX-Cray-8.7.input" inputs.
# Should be removed once the issue is fixed upstream and we apply the fix: https://gitlab.kitware.com/cmake/cmake/-/issues/22470.
rm -f %{_lib64dir}/lib{stdc++,gfortran}.a

export JAVA_HOME="%{java_home}"
bin/ctest --force-new-ctest-process --rerun-failed --output-on-failure

%files
%defattr(-,root,root)
%license Licenses
%{_bindir}/*
%{_datadir}/%{name}-*/*
%{_datadir}/aclocal/*
%{_datadir}/bash-completion/completions/*
%{_datadir}/emacs/site-lisp/cmake-mode.el
%{_datadir}/vim/vimfiles/*
%{_libdir}/rpm/macros.d/macros.cmake

%changelog
* Thu Mar 06 2025 corvus-callidus <108946721+corvus-callidus@users.noreply.github.com> - 3.30.3-5
- Patch vendored nghttp2 to fix CVE-2023-44487 and CVE-2023-35945

* Wed Jan 22 2025 Jyoti Kanase <v-jykanase@microsoft.com> - 3.30.3-4
- Fix CVE-2024-7264 and CVE-2024-9681

* Wed Jan 15 2025 Henry Beberman <henry.beberman@microsoft.com> - 3.30.3-3
- Patch vendored curl for CVE-2024-11053

* Thu Sep 26 2024 Jonathan Behrens <jbehrens@microsoft.com> - 3.30.3-2
- Fix CVE-2024-6197, CVE-2024-6874, and CVE-2024-8096

* Mon Sep 23 2024 Jonathan Behrens <jbehrens@microsoft.com> - 3.30.3-1
- Upgrade to 3.30.3 to address CVE-2024-24806

* Wed Jun 19 2024 Osama Esmail <osamaesmail@microsoft.com> - 3.29.6-1
- Auto-upgrade to 3.29.6 to address CVE-2023-28320 and CVE-2024-46218
- Adding 0001-manually-recreating-patches.patch to patch CVE-2024-28182

* Thu May 30 2024 Nicolas Guibourge <nicolasg@microsoft.com> - 3.28.2-6
- fix CVE-2024-24806 (cmake is built using libuv embedded in its code)

* Wed May 22 2024 Neha Agarwal <nehaagarwal@microsoft.com> - 3.28.2-5
- Bump release to build with new expat to fix CVE-2024-28757

* Tue May 21 2024 Neha Agarwal <nehaagarwal@microsoft.com> - 3.28.2-4
- Bump release to build with new libuv to fix CVE-2024-24806

* Thu May 16 2024 Daniel McIlvaney <damcilva@microsoft.com> - 3.28.2-3
- Sanitize license files

* Fri Mar 29 2024 Andrew Phelps <anphel@microsoft.com> - 3.28.2-2
- Fix JDK test issue

* Fri Feb 02 2024 Rakshaa Viswanathan <rviswanathan@microsoft.com> - 3.28.2-1
- Auto-upgrade to 3.28.2 - Upgrades for 3.0-dev
- Remove old CVE patches that don't apply

* Thu Oct 19 2023 Dan Streetman <ddstreet@ieee.org> - 3.21.4-10
- Patch vendored nghttp2 for CVE-2023-44487

* Tue Oct 10 2023 Mykhailo Bykhovtsev <mbykhovtsev@microsoft.com> - 3.21.4-9
- Patch vendored curl for CVE-2023-38545, CVE-2023-38546

* Wed Sep 06 2023 Brian Fjeldstad <bfjelds@microsoft.com> - 3.21.4-8
- Patch vendored nghttp2 for CVE-2023-35945

* Thu Jun 08 2023 Sam Meluch <sammeluch@microsoft.com> - 3.21.4-7
- Add source directory for when not building in source

* Thu Jun 08 2023 Sumedh Sharma <sumsharma@microsoft.com> - 3.21.4-6
- Patch vendored curl for CVE-2023-28322

* Tue Jun 06 2023 Dan Streetman <ddstreet@ieee.org> - 3.21.4-5
- Patch vendored curl for CVE-2023-23914

* Mon Apr 03 2023 Bala <balakumaran.kannan@microsoft.com> - 3.21.4-4
- Add build directory to %cmake macro to align with %cmake_build

* Mon Feb 06 2023 Daniel McIlvaney <damcilva@microsoft.com> - 3.21.4-3
- Patch CVE-2022-43551 in bundled curl

* Sun Dec 12 2021 Pawel Winogrodzki <pawelwi@microsoft.com> - 3.21.4-2
- Adding a workaround for two failing "ParseImplicitLinkInfo" test cases until a fix is available.
- Adjusted test command to re-run flaky tests.
- Bringing back generation of debug symbols.

* Mon Nov 15 2021 Pawel Winogrodzki <pawelwi@microsoft.com> - 3.21.4-1
- Update to version 3.21.4.
- License verified.

* Thu Dec 10 2020 Joe Schmitt <joschmit@microsoft.com> - 3.17.3-5
- Provide cmake-filesystem and isa version.

* Thu Nov 05 2020 Joe Schmitt <joschmit@microsoft.com> - 3.17.3-4
- Define additional cmake macros.

* Mon Sep 28 2020 Ruying Chen <v-ruyche@microsoft.com> - 3.17.3-3
- Update cmake version related macros
- Provide cmake3

* Mon Jul 06 2020 Eric Li <eli@microsoft.com> - 3.17.3-2
- Update Source0: to the new location

* Tue Jun 23 2020 Paul Monson <paulmon@microsoft.com> - 3.17.3-1
- Update to version 3.17.3

* Fri Jun 12 2020 Henry Beberman <henry.beberman@microsoft.com> - 3.12.1-7
- Temporarily disable generation of debug symbols.

* Sat May 09 2020 Nick Samson <nisamson@microsoft.com> - 3.12.1-6
- Added %%license line automatically

* Tue Sep 03 2019 Mateusz Malisz <mamalisz@microsoft.com> - 3.12.1-5
- Initial CBL-Mariner import from Photon (license: Apache2).

* Thu Jan 17 2019 Ankit Jain <ankitja@vmware.com> - 3.12.1-4
- Removed unnecessary libgcc-devel buildrequires

* Thu Dec 06 2018 <ashwinh@vmware.com> - 3.12.1-3
- Bug Fix 2243672. Add system provided libs.

* Sun Sep 30 2018 Bo Gan <ganb@vmware.com> - 3.12.1-2
- smp make (make -jN)
- specify /usr/lib as CMAKE_INSTALL_LIBDIR

* Fri Sep 07 2018 Ajay Kaher <akaher@vmware.com> - 3.12.1-1
- Upgrading version to 3.12.1
- Adding macros.cmake

* Fri Sep 29 2017 Kumar Kaushik <kaushikk@vmware.com> - 3.8.0-4
- Building using system expat libs.

* Thu Aug 17 2017 Kumar Kaushik <kaushikk@vmware.com> - 3.8.0-3
- Fixing make check bug # 1632102.

* Tue May 23 2017 Harish Udaiya Kumar <hudaiyakumar@vmware.com> - 3.8.0-2
- bug 1448414: Updated to build in parallel

* Fri Apr 07 2017 Anish Swaminathan <anishs@vmware.com>  3.8.0-1
- Upgrade to 3.8.0

* Thu Oct 06 2016 ChangLee <changlee@vmware.com> - 3.4.3-3
- Modified %check

* Tue May 24 2016 Priyesh Padmavilasom <ppadmavilasom@vmware.com> - 3.4.3-2
- GA - Bump release of all rpms

* Thu Feb 25 2016 Kumar Kaushik <kaushikk@vmware.com> - 3.4.3-1
- Updated version.

* Wed May 20 2015 Touseef Liaqat <tliaqat@vmware.com> - 3.2.1.2
- Updated group.

* Mon Apr 6 2015 Priyesh Padmavilasom <ppadmavilasom@vmware.com> - 3.2.1-1
- Update to 3.2.1

* Tue Nov 25 2014 Divya Thaluru <dthaluru@vmware.com> - 3.0.2-1
- Initial build. First version
